## 1.0.1 (2022-12-31)

### Feat

- Automatically find packages

## 1.0.0 (2022-12-31)

### Feat

- Added .gitignore
- Added pylintrc configuration

### Fix

- Added correct packages to include
- Removed forgotten print
- Fixed shared metaclass
- Fixed wrong condition

### Refactor

- Replaced setup.py with pyproject.toml
- Removed duplicate unique check
- Teplaced itertools.count calls
- Removed empty files
- Optimized get_sentence
- Optimized __generate_word for minimum length
- Optimized word generation code
- Removed dependency on itertools
- Removed not needed super arguments
- Removed deprecated USE_L10N
- Replaced os calls with pathlib
- Replaced separate CLI with __main__ module
- Updated sample project to newest django

## 0.2 (2016-09-25)

## 0.1 (2016-09-22)
